from zope.component import getSiteManager
from collective.linkedin.browser.interfaces import ICollectiveLinkedInManagement

class ProfileInfo(object):
    def get_settings(self):
        sm = getSiteManager()
        return sm.queryUtility(ICollectiveLinkedInManagement, name='linkedin_config')




from zope.app.component.hooks import getSite
from zope.component import getUtility
from zope.formlib import form
from zope.interface import implements
from zope.schema.fieldproperty import FieldProperty

from OFS.SimpleItem import SimpleItem
from Products.CMFCore.utils import getToolByName

from plone.app.controlpanel.form import ControlPanelForm

from collective.linkedin.browser.interfaces import ICollectiveLinkedInManagement
from collective.linkedin import LinkedInMessageFactory as _


ld_action_id = 'linkedin_company_info'
ci_url = "http://www.linkedin.com/companyInsider?script&useBorder=%s"

def add_company_info_js(portal,border=True,overwrite=False):
    pjs = portal.portal_javascripts

    if border:
        old_url = ci_url % "no"
        new_url = ci_url % "yes"
    else:
        old_url = ci_url % "yes"
        new_url = ci_url % "no"

    if overwrite:
        if pjs.getResource(old_url) is not None:
            pjs.manage_removeScript(id=old_url)
        if pjs.getResource(new_url) is None:
            pjs.manage_addScript(cacheable="False",compression="full",cookable="True",
                                 enabled="True", inline="True",id=new_url)
    else:
        if pjs.getResource(old_url) is None and pjs.getResource(new_url) is None:
            pjs.manage_addScript(cacheable="False",compression="full",cookable="True",
                                 enabled="True", inline="True",id=new_url)


def get_company_info_js_border(portal):
    pjs = portal.portal_javascripts
    if pjs.getResource(ci_url % "yes"):
        return True
    elif pjs.getResource(ci_url % "no"):
        return False
    else:
        return None

class LinkedInConfigurationForm(ControlPanelForm):
    form_fields = form.Fields(ICollectiveLinkedInManagement)
    label = _(u"LinkedIn settings form")
    description = _(u"Setup options of LinkedIn inside your plone")
    form_name = _(u"LinkedIn Settings")

class MissingAction(Exception):
    pass

class LinkedInConfiguration(SimpleItem):
    implements(ICollectiveLinkedInManagement)
    company_insider_widget = FieldProperty(ICollectiveLinkedInManagement['company_insider_widget'])

    def set_action_popup(self,value):
        site = getSite()
        site_actions = getToolByName(site,'portal_actions').site_actions
        if ld_action_id not in site_actions.objectIds():
            # I could not make this code work. Some change on porta_actions :-/
            # site_actions.addAction(ld_action_id,ld_action_id,'','',('View',),'site_actions')
            raise MissingAction('%s action in site_actions is missing' % ld_action_id)
        site_actions[ld_action_id].visible = bool(value)

    def get_action_popup(self):
        site = getSite()
        site_actions = getToolByName(site,'portal_actions').site_actions
        return ld_action_id in site_actions.objectIds() and site_actions[ld_action_id].visible
    action_popup = property(get_action_popup, set_action_popup)

    def set_border(self,value):
        site = getSite()
        add_company_info_js(site,overwrite=True,border=value)

    def get_border(self):
        site = getSite()
        return bool(get_company_info_js_border(site))
    border = property(get_border, set_border)


def form_adapter(context):
    return getUtility(ICollectiveLinkedInManagement, name='linkedin_config', context=context)



from zope.component import getSiteManager
from collective.linkedin.browser.interfaces import ICollectiveLinkedInManagement
from collective.linkedin.browser.config import LinkedInConfiguration
from collective.linkedin.browser.config import add_company_info_js

def setupVarious(context):

    # Ordinarily, GenericSetup handlers check for the existence of XML files.
    # Here, we are not parsing an XML file, but we use this text file as a
    # flag to check that we actually meant for this import step to be run.
    # The file is found in profiles/default.

    if context.readDataFile('collective.linkedin_various.txt') is None:
        return

    # Add additional setup code here

    portal = context.getSite()
    add_company_info_js(portal,overwrite=True)

    sm = getSiteManager()
    if not sm.queryUtility(ICollectiveLinkedInManagement, name='linkedin_config'):
        sm.registerUtility(LinkedInConfiguration(),
                           ICollectiveLinkedInManagement,
                           'linkedin_config')



from zope.component import getSiteManager
from collective.linkedin.browser.interfaces import ICollectiveLinkedInManagement

class CompanyInfo(object):
    def get_settings(self):
        sm = getSiteManager()
        return sm.queryUtility(ICollectiveLinkedInManagement, name='linkedin_config')

    def company_name(self):
        settings = self.get_settings()
        return settings and settings.company_insider_widget or None




from zope import schema
from zope.interface import Interface
from plone.theme.interfaces import IDefaultPloneLayer
from plone.portlets.interfaces import IPortletDataProvider
from plone.portlet.static.static import IStaticPortlet

from collective.linkedin import LinkedInMessageFactory as _


class IThemeSpecific(IDefaultPloneLayer):
    """Marker interface that defines a Zope 3 browser layer.
    """

class ICollectiveLinkedInManagement(Interface):
    """
    """
    company_insider_widget = schema.TextLine(
        title = _(u"Company Insider Widget"),
        required = False,
        description = _(u"Enter the company name"),
    )

    action_popup = schema.Bool(
        title = _(u"Site action pop up"),
        required = False,
        description = _(u"Check it if you want the site action popup"),
    )

    border = schema.Bool(
        title = _(u"Border"),
        required = False,
        description = _(u"Caution: if you enable popup, this needs to be checked."),
    )

class ICompanyInfoPortlet(IStaticPortlet):
    """ Defines a new portlet "Company Info" which takes properties of the existing static text portlet. """
    pass

class IProfileInfoPortlet(IPortletDataProvider):
    """ Defines a new portlet "Profile Info" """
    profile_id = schema.TextLine(
            title=_(u"LinkedIn user id"),
            description=_(u"Id of the LinkedIn user to show information"),
            default=u"",
            required=True)
    name = schema.TextLine(
            title=_(u"LinkedIn Name"),
            description=_(u"The name of the person"),
            default=u"",
            required=True)



from Products.Five.browser.pagetemplatefile import ViewPageTemplateFile
from plone.app.layout.viewlets.common import ViewletBase, SiteActionsViewlet

from collective.linkedin.browser.config import ld_action_id
from collective.linkedin.browser.company_info import CompanyInfo

class CustomSiteActionsViewlet(SiteActionsViewlet,CompanyInfo):
    index = ViewPageTemplateFile('templates/site_actions.pt')

    def render(self):
        return self.index()

    def action_visible(self):
        settings = self.get_settings()
        return settings and settings.action_popup or None

    def show_popup(self):
        return self.company_name() and self.action_visible()

    def linkedin_action_id(self):
        return ld_action_id



from zope.formlib import form
from zope.interface import implements

from plone.app.portlets.portlets import base
from plone.portlet.static import static

from Products.Five.browser.pagetemplatefile import ViewPageTemplateFile

from collective.linkedin.browser.company_info import CompanyInfo
from collective.linkedin.browser.profile_info import ProfileInfo
from collective.linkedin.browser.interfaces import ICompanyInfoPortlet, IProfileInfoPortlet
from collective.linkedin import LinkedInMessageFactory as _

class CompanyInfoRenderer(static.Renderer,CompanyInfo):
    """ Overrides static.pt in the rendering of the portlet. """
    render = ViewPageTemplateFile('templates/company_info.pt')

class CompanyInfoAssignment(static.Assignment):
    """ Assigner for company info portlet. """
    implements(ICompanyInfoPortlet)

    @property
    def title(self):
        return _(u"Company Info portlet")

class CompanyInfoAddForm(base.NullAddForm):
    """ Make sure that add form creates instances of our custom portlet instead
    of the base class portlet. """
    def create(self):
        return CompanyInfoAssignment()

class CompanyInfoEditForm(base.EditForm):
    form_fields = form.Fields()
    label = _(u"Edit Company Info")
    description = _(u"This portlet displays Company Info.")

class ProfileInfoRenderer(base.Renderer,ProfileInfo):
    """ Overrides static.pt in the rendering of the portlet. """
    render = ViewPageTemplateFile('templates/profile_info.pt')

class ProfileInfoAssignment(base.Assignment):
    """ Assigner for profile info portlet. """
    implements(IProfileInfoPortlet)

    profile_id = u''
    name = u''

    def __init__(self, name=u"", profile_id=u""):
        self.name = name
        self.profile_id = profile_id

    @property
    def title(self):
        return _(u"Profile Info portlet")

class ProfileInfoAddForm(base.AddForm):
    """ Make sure that add form creates instances of our custom
    portlet instead of the base class portlet. """
    form_fields = form.Fields(IProfileInfoPortlet)
    label = _(u"Add LinkedIn Profile Portlet")
    description = _(u"This portlet display a LinkedIn profile.")

    def create(self, data):
        return ProfileInfoAssignment(name=data.get('name', u''),
                                     profile_id=data.get('profile_id',u''))

class ProfileInfoEditForm(base.EditForm):
    form_fields = form.Fields(IProfileInfoPortlet)
    label = _(u"Edit Profile Info")
    description = _(u"This portlet displays Profile Info.")
